# selfstoredict
a python class delivering a dict that stores itself into a JSON file.

install:

"pip install git+https://github.com/markus61/selfstoredict.git"

usage:
all you do is, you call 'mydict = SelfStoreDict("mydict.json")'. from now on, whatever you add to the dict will be stored in 'mydict.json'.
please have a look at the supplied tests and the source.
have fun!

/markus
